summaryrefslogtreecommitdiff
path: root/src/gallium/auxiliary/draw/draw_private.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/gallium/auxiliary/draw/draw_private.h')
-rw-r--r--src/gallium/auxiliary/draw/draw_private.h5
1 files changed, 4 insertions, 1 deletions
diff --git a/src/gallium/auxiliary/draw/draw_private.h b/src/gallium/auxiliary/draw/draw_private.h
index 4d123cf8d9..59635d643b 100644
--- a/src/gallium/auxiliary/draw/draw_private.h
+++ b/src/gallium/auxiliary/draw/draw_private.h
@@ -227,7 +227,7 @@ void draw_pt_reset_vertex_ids( struct draw_context *draw );
/*******************************************************************************
* Primitive processing (pipelnie) code:
*/
boolean draw_pipeline_init( struct draw_context *draw );
@@ -241,6 +241,9 @@ void draw_pipeline_run( struct draw_context *draw,
const ushort *elts,
unsigned count );
+void draw_pipeline_flush( struct draw_context *draw,
+ unsigned flags );
+
boolean draw_need_pipeline(const struct draw_context *draw,
unsigned prim );
@@ -227,7 +227,7 @@ void draw_pt_reset_vertex_ids( struct draw_context *draw );
/*******************************************************************************
- * Primitive processing (pipelnie) code:
+ * Primitive processing (pipeline) code:
*/
boolean draw_pipeline_init( struct draw_context *draw );